![pyp logo](https://opensource.imageworks.com/images/large/pyp.jpg)

# pyp
The Pyed Piper: Python Power At the Prompt

This is the original pyp developed at Sony Pictures Imageworks that effectively replaces awk, sed, and other legacy command line tools with intuitive python syntax.

Please check out all of our [Documentation](https://thepyedpiper.github.io/pyp/)